from PIL import Image
from urllib.request import urlopen

class BootcampDSC:
    def IntroOOPIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/mvvXrj5/oop.jpg'))
        return self.gambar

    def ClassIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/gzpHLc3/class.jpg'))
        return self.gambar

    def MethodIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/hcbd2hd/class-method-attribute.jpg'))
        return self.gambar
    
    def InheritanceIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/HYj0Bcr/inherit.jpg'))
        return self.gambar

    def BMIIllustration(self):
        self.gambar = Image.open(urlopen('https://ukurandansatuan.com/wp-content/uploads/2016/07/uds-rumus-menghitung-BMI-400p.jpg'))
        return self.gambar





from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as fh:
        long_description = fh.read()

setup(name = 'BootcampDSC',
        version = '1.3.1',
        description = 'Data Literate Bootcamp DSC UMM',
        long_description = long_description,
        long_description_content_type = 'text/markdown', 
        # packages = ['BootcampDSC'],
        author = 'shandytp',
        author_email = 'shandytsalasa@gmail.com',
        packages = find_packages(),
        zip_safe = False)
